/* See LICENSE file for copyright and license details. */

#define XF86MonBrightnessDown 0x1008ff03
#define XF86MonBrightnessUp 0x1008ff02

/* appearance */
static const unsigned int borderpx = 1;        /* border pixel of windows */
static const unsigned int default_border = 1;  // to switch back to default border after dynamic border resizing via keybinds
static const unsigned int snap = 32;       /* snap pixel */
static const unsigned int gappih = 15;       /* horiz inner gap between windows */
static const unsigned int gappiv = 15;       /* vert inner gap between windows */
static const unsigned int gappoh = 20;       /* horiz outer gap between windows and screen edge */
static const unsigned int gappov = 20;       /* vert outer gap between windows and screen edge */
static int smartgaps = 0;        /* 1 means no outer gap when there is only one window */
static const unsigned int systraypinning = 0;   /* 0: sloppy systray follows selected monitor, >0: pin systray to monitor X */
static const unsigned int systrayspacing = 5;   /* systray spacing */
static const int systraypinningfailfirst = 1;   /* 1: if pinning fails,display systray on the 1st monitor,False: display systray on last monitor*/
static const int showsystray = 1;     /* 0 means no systray */
static const int showbar = 1;        /* 0 means no bar */
enum showtab_modes {
    showtab_never, showtab_auto, showtab_nmodes, showtab_always
};
static const int showtab = showtab_auto;
static const int toptab = True;
static const int topbar = 1;
static const int horizpadbar = 5;
static const int vertpadbar = 11;
static const int vertpadtab = 33;
static const int horizpadtabi = 15;
static const int horizpadtabo = 15;
static const int scalepreview = 4;
static const char *fonts[] = {"Mononoki Nerd Font:style:medium:size=10",
                              "Material Design Icons-Regular:size=10",
};
static const char dmenufont[] = "Mononoki Nerd Font:style:medium:size=10";
static const int colorfultag = 1;  /* 0 means use SchemeSel for selected non-vacant tag */

// theme
#include "themes/onedark.h"

static const char *colors[][3] = {
        /*               fg         bg         border   */
        [SchemeNorm]       = {gray3, black, gray2},
        [SchemeSel]        = {gray4, blue, blue},
        [TabSel]           = {blue, gray2, black},
        [TabNorm]          = {gray3, black, black},
        [SchemeTag]        = {gray3, black, black},
        [SchemeTag1]       = {blue, black, black},
        [SchemeTag2]       = {red, black, black},
        [SchemeTag3]       = {orange, black, black},
        [SchemeTag4]       = {green, black, black},
        [SchemeTag5]       = {pink, black, black},
        [SchemeLayout]     = {green, black, black},
        [SchemeBtnPrev]    = {green, black, black},
        [SchemeBtnNext]    = {yellow, black, black},
        [SchemeBtnClose]   = {red, black, black},
};

/* tagging */
static const char *tags[] = {"1", "2", "3", "4", "5", "6", "7", "8"};

static const int tagschemes[] = {SchemeTag1, SchemeTag2, SchemeTag3, SchemeTag4,
                                 SchemeTag5, SchemeTag4, SchemeTag2, SchemeTag3
};

static const unsigned int ulinepad = 5;    /* horizontal padding bwetween the underline and tag */
static const unsigned int ulinestroke = 2;    /* thickness / height of the underline */
static const unsigned int ulinevoffset = 0;    /* how far above the bottom of the bar the line should appear */
static const int ulineall = 0;    /* 1 to show underline on all tags, 0 for just the active ones */

static const Rule rules[] = {{ "X", NULL, NULL, 0, 0, -1 }};

/* layout(s) */
static const float mfact = 0.50; /* factor of master area size [0.05..0.95] */
static const int nmaster = 1;    /* number of clients in master area */
static const int resizehints = 0;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */

#define FORCE_VSPLIT 1  /* nrowgrid layout: force two clients to always split vertically */

#include "functions.h"

static const Layout layouts[] = {
        /* symbol     arrange function */
        {"[]=",  tile},    /* first entry is default */
        {"[M]",  monocle},
        {"[@]",  spiral},
        {"[\\]", dwindle},
        {"H[]",  deck},
        {"TTT",  bstack},
        {"===",  bstackhoriz},
        {"HHH",  grid},
        {"###",  nrowgrid},
        {"---",  horizgrid},
        {":::",  gaplessgrid},
        {"|M|",  centeredmaster},
        {">M>",  centeredfloatingmaster},
        {"|+|",  tatami},
        {"><>",  NULL},    /* no layout function means floating behavior */
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY, TAG) \
    { MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
    { MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
    { MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
    { MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static char dmenumon[2] = "0";
static const char *dmenucmd[] = {"dmenu_run", NULL};
static const char *termcmd[] = {"alacritty", NULL}; // change this to your term
static const char *rofi[] = {"rofi", "-show", "drun", "-font", "Mononoki Nerd Font 12", NULL};
static const char *layoutmenu_cmd = "/home/lemon/.dwm/layoutmenu.sh"; // change lemon to your username

static Key keys[] = {
        {MODKEY, XK_d, spawn, {.v = rofi}},
        {MODKEY, XK_Return, spawn, {.v = termcmd }},
        {MODKEY, XK_u, spawn, SHCMD("gnome-screenshot -i")},
        {MODKEY, XK_b, togglebar, {0}},
        {MODKEY, XK_j, focusstack, {.i = +1}},
        {MODKEY, XK_k, focusstack, {.i = -1}},
        {MODKEY, XK_i, incnmaster, {.i = +1}},
        {MODKEY, XK_c, incnmaster, {.i = -1}},
        {MODKEY, XK_h, setmfact, {.f = -0.05}},
        {MODKEY, XK_l, setmfact, {.f = +0.05}},
        {MODKEY | ShiftMask, XK_h, setcfact, {.f = +0.25}},
        {MODKEY | ShiftMask, XK_l, setcfact, {.f = -0.25}},
        {MODKEY | ShiftMask, XK_o, setcfact, {.f =  0.00}},
        {MODKEY | ShiftMask, XK_j, movestack, {.i = +1}},
        {MODKEY | ShiftMask, XK_k, movestack, {.i = -1}},
        {MODKEY | ShiftMask, XK_Return, zoom, {0}},
        {MODKEY, XK_Tab, view, {0}},
        {MODKEY | ControlMask, XK_t, togglegaps, {0}},
        {MODKEY, XK_q, killclient, {0}},
        {MODKEY, XK_t, setlayout, {.v = &layouts[0]}},
        {MODKEY | ControlMask, XK_comma, cyclelayout, {.i = -1}},
        {MODKEY | ControlMask, XK_period, cyclelayout, {.i = +1}},
        {MODKEY | ShiftMask, XK_space, togglefloating, {0}},
        {MODKEY, XK_f, togglefullscr, {0}},
        {MODKEY, XK_0, view, {.ui = ~0}},
        {MODKEY | ShiftMask, XK_comma, tagmon, {.i = -1}},
        {MODKEY | ShiftMask, XK_period, tagmon, {.i = +1}},

        TAGKEYS(XK_1, 0)
        TAGKEYS(XK_2, 1)
        TAGKEYS(XK_3, 2)
        TAGKEYS(XK_4, 3)
        TAGKEYS(XK_5, 4)
        TAGKEYS(XK_6, 5)
        TAGKEYS(XK_7, 6)
        TAGKEYS(XK_8, 7)

        {MODKEY | ControlMask, XK_q, quit, {0}},
        {MODKEY, XK_e, hidewin, {0}},
        {MODKEY | ShiftMask, XK_e, restorewin, {0}},

};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static Button buttons[] = {
        /* click        event mask   button   function        argument */
        {ClkLtSymbol,   0,           Button1, setlayout,      {0}},
        {ClkLtSymbol,   0,           Button3, setlayout,      {.v = &layouts[2]}},
        {ClkLtSymbol,   0,           Button3, layoutmenu,     {0}},
        {ClkWinTitle,   0,           Button2, zoom,           {0}},
        {ClkStatusText, 0,           Button2, spawn,          {.v = termcmd}},
        {ClkClientWin, MODKEY,       Button1, moveorplace,    {.i = 0}},
        {ClkClientWin, MODKEY,       Button2, togglefloating, {0}},
        {ClkClientWin, MODKEY,       Button3, resizemouse,    {0}},
        {ClkClientWin,  ControlMask, Button1, dragmfact,      {0}},
        {ClkClientWin,  ControlMask, Button3, dragcfact,      {0}},
        {ClkTagBar,     0,           Button1, view,           {0}},
        {ClkTagBar,     0,           Button3, toggleview,     {0}},
        {ClkTagBar,    MODKEY,       Button1, tag,            {0}},
        {ClkTagBar,    MODKEY,       Button3, toggletag,      {0}},
        {ClkTabBar,     0,           Button1, focuswin,       {0}},
        {ClkTabBar,     0,           Button1, focuswin,       {0}},
        {ClkTabPrev,    0,           Button1, movestack,      {.i = -1}},
        {ClkTabNext,    0,           Button1, movestack,      {.i = +1}},
        {ClkTabClose,   0,           Button1, killclient,     {0}},
};
